/*
    alarmdialog.cpp  -  The Alarm Dialog.

    Copyright (c) 2005      by Michal Larouche       <michael.larouche@kdemail.net>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/
#include "alarmdialog.h"

#include "blinklabel.h"

#include <QPushButton>
#include <QLabel>
#include <QHBoxLayout>
#include <QVBoxLayout>
#include <QSound>
#include <QFont>
#include <QColor>
#include <QCloseEvent>

const QString soundFile = QString("alarm.wav");

class AlarmDialog::Private
{
public:
	Private(const QString &tId, const QString &tMessage, bool tUseSound) :
		id(tId), message(tMessage), useSound(tUseSound), labelId(0L), labelMessage(0L), buttonClose(0L),
		buttonRestart(0L), soundAlarm(0L)
	{}

	QString id;
	QString message;
	bool useSound;

	BlinkLabel *labelId;
	BlinkLabel *labelMessage;
	QPushButton *buttonClose;
	QPushButton *buttonRestart;
	QSound *soundAlarm;
};

AlarmDialog::AlarmDialog(QWidget *parent, const QString &id, const QString &message, bool useSound)
: QDialog(parent)
{	
	d = new Private(id, message, useSound);
	
	initGUI();
}

AlarmDialog::~AlarmDialog()
{
	delete d;
}

void AlarmDialog::initGUI()
{
	QVBoxLayout *vLayout = new QVBoxLayout(this);

	d->labelId = new BlinkLabel(d->id, Qt::red, this);
	d->labelId->setFont(QFont("Times", 30, QFont::Bold));
	d->labelId->setColor1(Qt::yellow);
	d->labelId->setColor2(Qt::black);
	d->labelId->setAlignment(Qt::AlignCenter);
	d->labelId->slotStartBlink();
	vLayout->addWidget(d->labelId);

	d->labelMessage = new BlinkLabel(d->message, Qt::blue, this);
	d->labelMessage->setFont(QFont("Times", 24, QFont::Bold));
	d->labelMessage->setAlignment(Qt::AlignCenter);
	vLayout->addWidget(d->labelMessage);

	QHBoxLayout *buttonLayout = new QHBoxLayout();
	d->buttonRestart = new QPushButton(tr("RESTART"), this);
	buttonLayout->addWidget(d->buttonRestart);

	d->buttonClose = new QPushButton(tr("CLOSE"), this);
	d->buttonClose->setDefault(true);
	buttonLayout->addWidget(d->buttonClose);

	vLayout->addLayout(buttonLayout);
	
	if(d->useSound)
	{
		d->soundAlarm = new QSound(soundFile);
		d->soundAlarm->setLoops(-1); // Infinite
		d->soundAlarm->play();
	}

	connect(d->buttonRestart, SIGNAL(clicked()), this, SIGNAL(restartTimer()));
	connect(d->buttonRestart, SIGNAL(clicked()), this, SLOT(accept()));

	connect(d->buttonClose, SIGNAL(clicked()), this, SLOT(accept()));
}

void AlarmDialog::accept()
{
	QDialog::accept();
	if(d->useSound)
	{
		d->soundAlarm->stop();
	}
}

void AlarmDialog::closeEvent(QCloseEvent *event)
{
	accept();
}
