/*
    blinklabel.cpp  -  A label where the background blink

    Copyright (c) 2005      by Michal Larouche       <michael.larouche@kdemail.net>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/
#include "blinklabel.h"

#include <QPalette>
#include <QColor>
#include <QTimer>

class BlinkLabel::Private
{
public:
	Private() 
		: blinkTimer(0L), swap(false)
	{}

	QTimer *blinkTimer;
	QPalette color1;
	QPalette color2;
	bool swap;
};

BlinkLabel::BlinkLabel(const QString &text, const QColor &textColor, QWidget *parent)
: QLabel(text, parent)
{
	d = new Private;

	QPalette temp = palette();
	temp.setColor(QPalette::Text, textColor);
	setPalette(temp);

	d->color1 = palette();
	d->color2 = palette();

	setTextFormat(Qt::RichText);
	setFrameStyle(QFrame::Sunken | QFrame::WinPanel);
}

BlinkLabel::~BlinkLabel()
{
	delete d;
}

void BlinkLabel::setColor1(const QColor &color1)
{
	d->color1.setColor(QPalette::Background, color1);
}

void BlinkLabel::setColor2(const QColor &color2)
{
	d->color2.setColor(QPalette::Background, color2);
}

void BlinkLabel::slotStartBlink()
{
	if(d->blinkTimer != 0L)
	{
		d->blinkTimer->deleteLater();
		d->blinkTimer = 0L;
	}

	d->blinkTimer = new QTimer(this);
	connect(d->blinkTimer, SIGNAL(timeout()), this, SLOT(updateBlink()));
	d->blinkTimer->start(500);
}

void BlinkLabel::updateBlink()
{
	if(d->swap)
	{
		setPalette(d->color2);
		d->swap = false;
	}
	else
	{
		setPalette(d->color1);
		d->swap = true;
	}
}
