/*
    multitimermainwindow.cpp  -  The Main Window.

    Copyright (c) 2005      by Michal Larouche       <michael.larouche@kdemail.net>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/
#include "multitimermainwindow.h"

#include "multitimerview.h"

#include <QApplication>
#include <QAction>
#include <QMenu>
#include <QMenuBar>
#include <QSettings>
#include <QMessageBox>
#include <QCloseEvent>

MultiTimerMainWindow::MultiTimerMainWindow(QWidget *parent)
: QMainWindow(parent, Qt::WindowStaysOnTopHint)
{
	view = new MultiTimerView(this);

	view->readSettings();

	setWindowTitle(tr("Multi Timer"));
	qApp->setWindowIcon(QIcon(":/mainIcon.png"));
	createActions();

	setCentralWidget(view);

	readSettings();
}

MultiTimerMainWindow::~MultiTimerMainWindow()
{

}

void MultiTimerMainWindow::createActions()
{
	QAction *quitAction = new QAction(tr("&Quit"), this);
	quitAction->setShortcut(tr("Ctrl+Q"));
	connect(quitAction, SIGNAL(triggered()), this, SLOT(fileQuit()));

	QAction *addTimerAction = new QAction(tr("&Add Timer"), this);
	connect(addTimerAction, SIGNAL(triggered()), view, SLOT(addTimer()));
	QAction *removeTimerAction = new QAction(tr("&Remove Timer"), this);
	connect(removeTimerAction, SIGNAL(triggered()), view, SLOT(removeTimer()));

	QAction *aboutAction = new QAction(tr("&About Multi Timer..."), this);
	connect(aboutAction, SIGNAL(triggered()), this, SLOT(helpAbout()));
	QAction *aboutQtAction = new QAction(tr("About &Qt..."), this);
	connect(aboutQtAction, SIGNAL(triggered()), qApp, SLOT(aboutQt()));

	QMenu *fileMenu = menuBar()->addMenu(tr("&File"));
	fileMenu->addAction(quitAction);

	QMenu *timerMenu = menuBar()->addMenu(tr("&Timer"));
	timerMenu->addAction(addTimerAction);
	timerMenu->addAction(removeTimerAction);

	QMenu *helpMenu = menuBar()->addMenu(tr("&Help"));
	helpMenu->addAction(aboutAction);
	helpMenu->addAction(aboutQtAction);
}

void MultiTimerMainWindow::readSettings()
{
	QSettings settings(QSettings::UserScope, "shockdev.ca.tc", "MultiTimerQt"); 

	settings.beginGroup("MultiTimerMainWindow");
	resize(settings.value("size", QSize(430, 300)).toSize());
	move(settings.value("pos", QPoint(300, 200)).toPoint());
	settings.endGroup();

	settings.setValue("apprunning", true);
	settings.sync(); // Make sure that this value is written.
}

void MultiTimerMainWindow::writeSettings()
{
	QSettings settings(QSettings::UserScope, "shockdev.ca.tc", "MultiTimerQt"); 

	settings.beginGroup("MultiTimerMainWindow");
	settings.setValue("size", size());
	settings.setValue("pos", pos());
	settings.endGroup();

	settings.setValue("apprunning", false);
}

void MultiTimerMainWindow::fileQuit()
{
	if(!view->isTimerActive())
	{
		view->writeSettings();
		writeSettings();
		qApp->quit();
	}
	else
	{
		QMessageBox::critical(this, tr("Error"), tr("You still have running timer(s) !"), QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
	}
}

void MultiTimerMainWindow::helpAbout()
{
	QMessageBox::information(this, 
		tr("About Multi Timer"),
		tr("Multi Timer 1.0\n"
		   "Copyright 2005 Michal Larouche (michael.larouche@kdemail.net)\n\n"
		   "This program is free software; you can redistribute it and/or modify\n"
		   "it under the terms of the GNU General Public License version 2 as published by\n"
		   "the Free Software Foundation"),
		   QMessageBox::Ok);
}

void MultiTimerMainWindow::closeEvent(QCloseEvent *event)
{
	if(!view->isTimerActive())
	{
		view->writeSettings();
		writeSettings();
		event->accept();
	}
	else
	{
		QMessageBox::critical(this, tr("Error"), tr("You still have running timer(s) !"), QMessageBox::Ok, QMessageBox::NoButton, QMessageBox::NoButton);
		event->ignore();
	}
}
