/*
    timercontrolwidget.cpp  -  Timer control widget.

    Copyright (c) 2005      by Michal Larouche       <michael.larouche@kdemail.net>

    *************************************************************************
    *                                                                       *
    * This program is free software; you can redistribute it and/or modify  *
    * it under the terms of the GNU General Public License as published by  *
    * the Free Software Foundation; either version 2 of the License, or     *
    * (at your option) any later version.                                   *
    *                                                                       *
    *************************************************************************
*/
#include "timercontrolwidget.h"

#include <QHBoxLayout>
#include <QPushButton>
#include <QTimeEdit>
#include <QLabel>
#include <QTime>
#include <QSplitter>
#include <QSizePolicy>
#include <QFontMetrics>
#include <QMessageBox>
#include <QPalette>
#include <QColor>

class TimerControlWidget::Private
{
public:
	Private() :
	  button(0L), timeEdit(0L), label(0L), buttonState(false)
	{}

	int index;

	QPushButton *button;
	QTimeEdit *timeEdit;
	QLabel *label;
	bool buttonState;
	QPalette paletteActive;
	QPalette paletteIdle;
};

const QString metricString = QString("abcdefghijklmnopqrstuvwxyz01");

TimerControlWidget::TimerControlWidget(QWidget *parent, int index)
: QGroupBox(parent)
{
	d = new Private;

	d->index = index;
	
	d->paletteActive = palette();
	d->paletteActive.setColor(QPalette::Text, Qt::red);

	d->paletteIdle = palette();
	d->paletteIdle.setColor(QPalette::Text, Qt::blue);

	createSubWidgets();
}

TimerControlWidget::~TimerControlWidget()
{
	delete d;
}

int TimerControlWidget::index() const
{
	return d->index;
}

void TimerControlWidget::setIndex(int index)
{
	d->index = index;
}

void TimerControlWidget::createSubWidgets()
{
	QHBoxLayout *layout = new QHBoxLayout(this);

	d->label = new QLabel(QString::number(d->index), this);
	d->label->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
	QFontMetrics fm(d->label->font());
	d->label->setMinimumSize(fm.width(metricString), fm.height());
	layout->addWidget(d->label);

	d->timeEdit = new QTimeEdit(this);
	d->timeEdit->setPalette(d->paletteIdle);
	d->timeEdit->setReadOnly(true);
	layout->addWidget(d->timeEdit);

	d->button = new QPushButton(tr("START"), this);
	layout->addWidget(d->button);
	connect(d->button, SIGNAL(clicked()), this, SIGNAL(buttonClicked()));

	layout->addWidget(new QSplitter(Qt::Horizontal, this));
}

void TimerControlWidget::toggleButton()
{
	d->buttonState = !d->buttonState;
	d->button->setText(d->buttonState ? tr("STOP") : tr("START"));

	d->timeEdit->setPalette(d->buttonState ? d->paletteActive : d->paletteIdle);
}

void TimerControlWidget::updateTimeEdit(const QTime &time)
{
	d->timeEdit->setTime(time);
}

void TimerControlWidget::updateText(const QString &text)
{
	d->label->setText(text);
}
